/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes.ejb;

import java.util.List;

import javax.ejb.Remove;
import javax.ejb.Stateful;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.PersistenceContextType;

import org.jboss.security.annotation.SecurityDomain;

import br.urca.solicitacoes.DadosAdministrador;
import br.urca.solicitacoes.DadosFuncionarioComPermissoes;
import br.urca.solicitacoes.Funcionario;
import br.urca.solicitacoes.GerenciamentoFuncionariosException;
import br.urca.solicitacoes.IGerenciadorFuncionarios;
import br.urca.solicitacoes.Setor;

@Stateful
@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
@SecurityDomain(DominioSeguranca.SOLICITACOES)
public class GerenciadorFuncionariosBean implements IGerenciadorFuncionarios
{
	@PersistenceContext(type = PersistenceContextType.EXTENDED)
	private EntityManager fGE;
	
	private Setor fSetorAtual;

	@Override
	public void definirSetorAtual(Setor setorAtual)
	{
		if (setorAtual == null)
		{
			throw new NullPointerException("Setor atual nulo.");
		}
		fSetorAtual = setorAtual;
	}

	@Override
	public List<Funcionario> localizarAdministradoresSetorAtual()
	{
		checarSetorAtualDefinido();
		
		@SuppressWarnings("unchecked")
		List<Funcionario> administradoresSetorAtual =
			(List<Funcionario>) fGE.createQuery(
			FiltroSituacoesAtivasFuncionario.filtrar(
			"SELECT f " +
			"FROM Funcionario f " +
			"   JOIN f.administracoes a " +
			"WHERE a.setor = :setorAtual " +
			"ORDER BY f.nome, f.setor.nome")).
			setParameter("setorAtual", fSetorAtual).
			getResultList();
		return administradoresSetorAtual;
	}

	@Override
	public List<Setor> localizarSetores(short codigoInstituicao)
	{
		return null;
	}

	@Override
	public List<DadosAdministrador> localizarAdministradores()
	{
		return null;
	}

	@Override
	public void adicionarAdministrador(
		int codigoFuncionario, Setor setorAdministracao)
		throws GerenciamentoFuncionariosException
	{
	}

	@Override
	public void removerAdministrador(DadosAdministrador administrador)
		throws GerenciamentoFuncionariosException
	{
	}

	@Override
	public List<DadosFuncionarioComPermissoes> localizarFuncionarios()
	{
		return null;
	}

	@Override
	public void adicionarFuncionarioDeOutroSetor(int codigoFuncionario)
		throws GerenciamentoFuncionariosException
	{
	}

	@Override
	@TransactionAttribute(TransactionAttributeType.REQUIRED)
	@Remove
	public void atualizar()
	{
	}

	@Override
	@Remove
	public void cancelar()
	{
	}
	
	private void checarSetorAtualDefinido()
	{
		if (fSetorAtual == null)
		{
			throw new AssertionError("Setor atual no definido.");
		}
	}
}
