/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes.ejb;

import java.util.Comparator;
import java.util.Set;
import java.util.TreeSet;

import javax.annotation.Resource;
import javax.ejb.EJB;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;

import org.jboss.security.annotation.SecurityDomain;

import br.urca.solicitacoes.AdministracaoFuncionario;
import br.urca.solicitacoes.DadosFuncionarioAutenticado;
import br.urca.solicitacoes.Funcionario;
import br.urca.solicitacoes.ILocalizadorFuncionarioAutenticado;
import br.urca.solicitacoes.PermissaoFuncionario;
import br.urca.solicitacoes.Setor;
import br.urca.solicitacoes.TipoPermissao;

@Stateless
@SecurityDomain(DominioSeguranca.SOLICITACOES)
public class LocalizadorFuncionarioAutenticadoBean
	implements ILocalizadorFuncionarioAutenticado
{
	@EJB
	private ILocalizadorFuncionario fLocalizadorFuncionario;
	@Resource
	private SessionContext fContexto;

	@Override
	public DadosFuncionarioAutenticado localizarFuncionarioAutenticado()
	{
		Funcionario funcionario =
			fLocalizadorFuncionario.localizarFuncionarioAutenticado();
		
		verificarIntegridadeSetorSolicitacoes(funcionario);
		
		Setor setorPadrao = funcionario.getSetorPadrao();
		Set<Setor> setores = obterSetores(funcionario);
		boolean administradorGeral =
			fContexto.isCallerInRole(Funcionario.FUNCAO_ADMINISTRADOR_GERAL);
		boolean administrador = funcionario.administrador(setorPadrao);
		Set<TipoPermissao> permissoes =
			funcionario.obterPermissoes(setorPadrao);
		
		return new DadosFuncionarioAutenticado(
			funcionario.getMatricula(),
			funcionario.getNome(),
			setorPadrao,
			setores,
			funcionario.getEmail(),
			funcionario.isSenhaAlterada(),
			administradorGeral,
			administrador,
			permissoes
		);
	}
	
	private void verificarIntegridadeSetorSolicitacoes(Funcionario funcionario)
	{
		if (funcionario.getSetorSolicitacoes() != null)
		{
			if (funcionario.getSetorSolicitacoes().equals(
				funcionario.getSetor()) ||
				!funcionario.possuiPermissoes(funcionario.getSetorPadrao()))
			{
				funcionario.setSetorSolicitacoes(null);
			}
		}
	}

	private Set<Setor> obterSetores(Funcionario funcionario)
	{
		final Comparator<Setor> ORDEM_POR_NOME =
			new Comparator<Setor>()
			{
				public int compare(Setor setor1, Setor setor2)
				{
					return setor1.getNome().compareTo(setor2.getNome());
				}
			};
		Set<Setor> setores = new TreeSet<Setor>(ORDEM_POR_NOME);
		
		if (funcionario.getSetor() != null)
		{
			setores.add(funcionario.getSetor());
		}
		for (AdministracaoFuncionario administracao :
			funcionario.getAdministracoes())
		{
			setores.add(administracao.getSetor());
		}
		for (PermissaoFuncionario permissao : funcionario.getPermissoes())
		{
			setores.add(permissao.getSetor());
		}
		
		return setores;
	}
}
