/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes.ejb;

import java.util.Date;

import javax.ejb.Stateless;
import javax.ejb.TransactionAttribute;
import javax.ejb.TransactionAttributeType;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;
import javax.persistence.Query;
import javax.persistence.TemporalType;

import br.urca.solicitacoes.DadosFuncionarioAutenticado;
import br.urca.solicitacoes.IVerificadorNovasSolicitacoes;

@Stateless
@TransactionAttribute(TransactionAttributeType.NOT_SUPPORTED)
public class VerificadorNovasSolicitacoesBean
	implements IVerificadorNovasSolicitacoes
{
	@PersistenceContext
	private EntityManager fGE;
	
	public Date verificarNovasSolicitacoes(Date dataUltimaSolicitacaoRecebida,
		DadosFuncionarioAutenticado usuarioAutenticado)
	{
		Utils.validarPermissaoUsuarioParaConsultar(usuarioAutenticado);
		
		Query comando;
		if (usuarioAutenticado.getPermissoes().isConsultarTodasSolicitacoes())
		{
			comando = fGE.createQuery(
				"SELECT MAX(a.dataEnvio) " +
				"FROM Andamento a " +
				"WHERE a.dataEnvio > :dataUltimaSolicitacaoRecebida AND " +
				"   a.setorDestino = :setorAtual");
		}
		else
		{
			comando = fGE.createQuery(
				"SELECT MAX(a.dataEnvio) " +
				"FROM Andamento a " +
				"WHERE a.dataEnvio > :dataUltimaSolicitacaoRecebida AND " +
				"   a.setorDestino = :setorAtual AND " +
				"   a.solicitacao.solicitante.matricula = " +
				"   :matriculaUsuarioAutenticado").
				setParameter("matriculaUsuarioAutenticado",
				usuarioAutenticado.getMatricula());
		}
		Date novaDataUltimaSolicitacaoRecebida = (Date) comando.
			setParameter("dataUltimaSolicitacaoRecebida",
				dataUltimaSolicitacaoRecebida, TemporalType.TIMESTAMP).
			setParameter("setorAtual", usuarioAutenticado.getSetor()).
			getSingleResult();
		return novaDataUltimaSolicitacaoRecebida;
	}
}
