/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes;

import java.io.Serializable;

import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.NamedQuery;
import javax.persistence.QueryHint;
import javax.persistence.Table;

@Entity
@Table(name = "GE_SETORES")
@NamedQuery(
	name = Setor.SQL_LOCALIZAR_POR_CODIGO_INSTITUICAO,
	query =
		"SELECT s " +
		"FROM Setor s " +
		"WHERE s.codigo.codigoInstituicao = :codigoInstituicao " +
		"ORDER BY s.nome",
	hints = {
		@QueryHint(name = "org.hibernate.cacheable", value = "true"),
		@QueryHint(name = "org.hibernate.cacheRegion",
			value = "query.Setor.LocalizarPorCodigoInstituicao")
	}
)
@org.hibernate.annotations.Cache(usage =
	org.hibernate.annotations.CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class Setor implements Serializable
{
	private static final long serialVersionUID = -5288373769671061953L;

	public static final String SQL_LOCALIZAR_POR_CODIGO_INSTITUICAO =
		"Setor.localizarPorCodigoInstituicao";

	private CodigoSetor codigo;
	private String nome;	

	@EmbeddedId
	public CodigoSetor getCodigo()
	{
		return codigo;
	}

	public void setCodigo(CodigoSetor codigo)
	{
		this.codigo = codigo;
	}

	public String getNome()
	{
		return nome;
	}

	public void setNome(String nome)
	{
		this.nome = nome;
	}

	@Override
	public boolean equals(Object obj)
	{
		if (this == obj)
		{
			return true;
		}
		if (obj == null)
		{
			return false;
		}
		if (getClass() != obj.getClass())
		{
			return false;
		}
		
		Setor outro = (Setor) obj;
		
		if (codigo == null)
		{
			if (outro.getCodigo() != null)
			{
				return false;
			}
		}
		else if (!codigo.equals(outro.getCodigo()))
		{
			return false;
		}
		return true;
	}
	
	@Override
	public int hashCode()
	{
		return codigo == null ? 0 : codigo.hashCode();
	}
	
	@Override
	public String toString()
	{
		return getNome() == null ? "" : getNome();
	}
}
