/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.JoinColumn;
import javax.persistence.JoinColumns;
import javax.persistence.ManyToOne;
import javax.persistence.NamedQuery;
import javax.persistence.QueryHint;
import javax.persistence.Table;

@Entity
@Table(name = "SO_TIPOS_SOLICITACAO")
@NamedQuery(
	name = TipoSolicitacao.SQL_LOCALIZAR_TODOS,
	query =
		"SELECT t " +
		"FROM TipoSolicitacao t " +
		"WHERE t.tipoUsuario = :tipoUsuario " +
		"ORDER BY t.descricao",
	hints = {
		@QueryHint(name = "org.hibernate.cacheable", value = "true"),
		@QueryHint(name = "org.hibernate.cacheRegion",
			value = "query.TipoSolicitacao.LocalizarTodos")
	}
)
@org.hibernate.annotations.Cache(usage =
	org.hibernate.annotations.CacheConcurrencyStrategy.NONSTRICT_READ_WRITE)
public class TipoSolicitacao
{
	public static final String GERAL_STRING                           = "1";
	public static final String MATERIAL_STRING                        = "2";
	public static final String RESERVA_LABORATORIO_INFORMATICA_STRING = "3";
	
	public static final short GERAL                           =
		Short.parseShort(GERAL_STRING);
	public static final short MATERIAL                        =
		Short.parseShort(MATERIAL_STRING);
	public static final short RESERVA_LABORATORIO_INFORMATICA =
		Short.parseShort(RESERVA_LABORATORIO_INFORMATICA_STRING);
	
	public static final String SQL_LOCALIZAR_TODOS =
		"TipoSolicitacao.localizarTodos";
	
	private short codigo;
	private String descricao;
	private Setor setorDestino;
	private TipoUsuario tipoUsuario;
	
	@Id
	@Column(name = "COD_TIPO_SOLICITACAO")
	public short getCodigo()
	{
		return codigo;
	}

	public void setCodigo(short codigo)
	{
		this.codigo = codigo;
	}

	public String getDescricao()
	{
		return descricao;
	}

	public void setDescricao(String descricao)
	{
		this.descricao = descricao;
	}

	@ManyToOne
	@JoinColumns({
		@JoinColumn(name = "COD_INSTITUICAO_DESTINO", 
			referencedColumnName = "COD_INSTITUICAO"),
		@JoinColumn(name = "COD_SETOR_DESTINO", 
			referencedColumnName = "COD_SETOR")
	})
	public Setor getSetorDestino()
	{
		return setorDestino;
	}

	public void setSetorDestino(Setor setorDestino)
	{
		this.setorDestino = setorDestino;
	}

	@Column(name = "TIPO_USUARIO")
	public TipoUsuario getTipoUsuario()
	{
		return tipoUsuario;
	}

	public void setTipoUsuario(TipoUsuario tipoUsuario)
	{
		this.tipoUsuario = tipoUsuario;
	}
}
