/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes.web;

import javax.faces.bean.ManagedBean;
import javax.faces.bean.SessionScoped;

import br.urca.solicitacoes.DadosAtualizacaoFuncionarioAutenticado;
import br.urca.solicitacoes.DadosSenha;
import br.urca.solicitacoes.IGerenciadorFuncionarioAutenticado;
import br.urca.solicitacoes.SenhaException;
import br.urca.solicitacoes.Setor;
import br.urca.solicitacoes.SolicitacoesException;
import br.urca.util.UtilsString;

@ManagedBean
@SessionScoped
public class DadosPessoais extends AlteracaoSenha
{
	private String fEmail;
	private Setor fSetorPadrao;
	private Setor fSetorPadraoAntigo;
	private boolean fAlteracaoSenhaVisivel;
	private String fMensagemErroSenha;
	
	public String getEmail()
	{
		return fEmail;
	}

	public void setEmail(String email)
	{
		fEmail = email;
	}
	
	public Setor getSetorPadrao()
	{
		return fSetorPadrao;
	}
	
	public void setSetorPadrao(Setor setorPadrao)
	{
		fSetorPadrao = setorPadrao;
	}
	
	public boolean isAlteracaoSenhaVisivel()
	{
		return fAlteracaoSenhaVisivel;
	}
	
	public String getMensagemErroSenha()
	{
		return fMensagemErroSenha;
	}

	public String exibir()
	{
		fEmail = FuncionarioAutenticado.getInstancia().getEmail();
		fSetorPadrao = FuncionarioAutenticado.getInstancia().getSetor();
		fSetorPadraoAntigo = fSetorPadrao;
		fAlteracaoSenhaVisivel = false;
		
		return Navegacao.DADOS_PESSOAIS;
	}
	
	public void exibirAlteracaoSenha()
	{
		fAlteracaoSenhaVisivel = true;
		fMensagemErroSenha = null;
		Utils.focalizarComponente("form:senhas:senhaAtual", true);
	}
	
	public void ocultarDadosSenha()
	{
		fAlteracaoSenhaVisivel = false;
	}
	
	public String atualizar()
	{
		try
		{
			if (UtilsString.nuloOuVazio(fEmail))
			{
				fEmail = null;
			}
			
			DadosAtualizacaoFuncionarioAutenticado dados;
			if (fAlteracaoSenhaVisivel)
			{
				DadosSenha dadosSenha =	new DadosSenha(
					getSenhaAtual(), getNovaSenha(), getConfirmacaoNovaSenha());
				dados = new DadosAtualizacaoFuncionarioAutenticado(
					fEmail, fSetorPadrao, dadosSenha);
			}
			else
			{
				dados =	new DadosAtualizacaoFuncionarioAutenticado(
					fEmail, fSetorPadrao);
			}
			IGerenciadorFuncionarioAutenticado atualizadorFuncionario =
				LocalizadorEJB.localizar(
				IGerenciadorFuncionarioAutenticado.class);
			atualizadorFuncionario.atualizarFuncionario(dados);
			
			if (fSetorPadrao.equals(fSetorPadraoAntigo))
			{
				FuncionarioAutenticado.getInstancia().setEmail(fEmail);
			}
			else
			{
				FuncionarioAutenticado.atualizar();
			}
			
			Mensagem.definirMensagem("Dados pessoais atualizados com sucesso.");
			return Navegacao.MENSAGEM;
		}
		catch (Exception ex)
		{
			fMensagemErroSenha = null;
			if (ex.getCause() != null)
			{
				if (ex.getCause().getClass() == SenhaException.class)
				{
					fMensagemErroSenha = ex.getCause().getMessage();
				}
				else
				{
					adicionarMensagemEmailInvalido();
				}
				return null;
			}
			throw new SolicitacoesException(ex);
		}
	}

	private void adicionarMensagemEmailInvalido()
	{
		Utils.adicionarMensagemErro("foco", "E-mail invlido.");
	}
}