/**
 * @autor Marcos Antonio Pereira Silva
 */

package br.urca.solicitacoes.web;

import java.io.IOException;
import java.text.DateFormat;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.Map;

import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.event.PhaseEvent;
import javax.faces.event.PhaseId;
import javax.faces.event.PhaseListener;
import javax.servlet.http.HttpServletResponse;

import br.urca.solicitacoes.IVerificadorNovasSolicitacoes;

public class SolicitacoesPhaseListener implements PhaseListener
{
	private static final long serialVersionUID = -37186944453154587L;
	
	public PhaseId getPhaseId()
	{
		return PhaseId.RESTORE_VIEW;
	}

	public void beforePhase(PhaseEvent e)
	{
		if (requisicaoAjax(e))
		{
			processarRequisicaoAjax(e);
			e.getFacesContext().responseComplete();
		}
	}

	public void afterPhase(PhaseEvent e)
	{
		if (!requisicaoAjax(e))
		{
			ControladorAcessoPagina controladorAcessoPagina =
				new ControladorAcessoPagina();
			controladorAcessoPagina.controlarAcessoPagina(e);
		}
	}

	private boolean requisicaoAjax(PhaseEvent e)
	{
		FacesContext contexto = e.getFacesContext();
		Map<String, String> parametrosRequisicao =
			contexto.getExternalContext().getRequestParameterMap();
		return parametrosRequisicao.get("ajax") != null;
	}

	private void processarRequisicaoAjax(PhaseEvent e)
	{
		verificarNovasSolicitacoes(e);
	}

	private void verificarNovasSolicitacoes(PhaseEvent e)
	{
		try
		{
			ExternalContext contextoExterno =
				e.getFacesContext().getExternalContext();
			
			DateFormat formato = new SimpleDateFormat(
				ConsultaSolicitacoes.FORMATO_DATA_ULTIMA_SOLICITACAO_RECEBIDA);
			Map<String, String> parametrosRequisicao =
				contextoExterno.getRequestParameterMap();
			Date dataUltimaSolicitacaoRecebida =
				formato.parse(parametrosRequisicao.get("data"));
			
			IVerificadorNovasSolicitacoes verificadorNovasSolicitacoes =
				LocalizadorEJB.localizar(IVerificadorNovasSolicitacoes.class);
			Date novaDataUltimaSolicitacaoRecebida =
				verificadorNovasSolicitacoes.verificarNovasSolicitacoes(
				dataUltimaSolicitacaoRecebida,
				FuncionarioAutenticado.getInstancia());
			
			HttpServletResponse resposta =
				(HttpServletResponse) contextoExterno.getResponse();
			boolean existemNovasSolicitacoes =
				novaDataUltimaSolicitacaoRecebida != null;
			if (existemNovasSolicitacoes)
			{
				resposta.getWriter().write(
					formato.format(novaDataUltimaSolicitacaoRecebida));
			}
			else
			{
				resposta.getWriter().write("");
			}
		}
		catch (ParseException ex)
		{
			ex.printStackTrace();
		}
		catch (IOException ex)
		{
			ex.printStackTrace();
		}
		catch (Exception ex)
		{
			ex.printStackTrace();
		}
	}
}
